require 'json'

package = JSON.parse(File.read(File.join(__dir__, 'package.json')))
folly_compiler_flags = '-DFOLLY_NO_CONFIG -DFOLLY_MOBILE=1 -DFOLLY_USE_LIBCPP=1 -Wno-comma -Wno-shorten-64-to-32'

NativeWrapperVersion = '6.1.1.1'

Pod::Spec.new do |s|
    s.name              = 'RNScanbotSDK'
    s.version           = package['version']
    s.summary           = package['description']
    s.homepage          = package['homepage']
    s.authors           = package['author']
    s.license           = { :type => 'Commercial', :file => 'LICENSE' }

    s.platforms    = { :ios => "13.0" }

    s.source            = { :http => 'https://download.scanbot.io/sdk/react-native/react-native-scanbot-sdk-' + package['version'] + '.tgz' }

    s.source_files = "ios/**/*.{h,m,mm}"

    # Use install_modules_dependencies helper to install the dependencies if React Native version >=0.71.0.
    if respond_to?(:install_modules_dependencies, true)
      install_modules_dependencies(s)
    else
      s.dependency "React-Core"

      # Don't install the dependencies when we run `pod install` in the old architecture.
      if ENV['RCT_NEW_ARCH_ENABLED'] == '1' then
        s.compiler_flags = folly_compiler_flags + " -DRCT_NEW_ARCH_ENABLED=1"
        s.pod_target_xcconfig    = {
            "HEADER_SEARCH_PATHS" => "\"$(PODS_ROOT)/boost\"",
            "OTHER_CPLUSPLUSFLAGS" => "-DFOLLY_NO_CONFIG -DFOLLY_MOBILE=1 -DFOLLY_USE_LIBCPP=1",
            "CLANG_CXX_LANGUAGE_STANDARD" => "c++17"
        }
        s.dependency "React-Codegen"
        s.dependency "RCT-Folly"
        s.dependency "RCTRequired"
        s.dependency "RCTTypeSafety"
        s.dependency "ReactCommon/turbomodule/core"
      end
    end

    s.subspec 'ALL' do |all|
        all.dependency 'ScanbotSDKNativeWrapper/ALL', NativeWrapperVersion
        all.ios.vendored_frameworks = 'ScanbotSDK.framework', 'ScanbotSDKNativeWrapper.framework'
        all.source_files = "ios/**/*.{h,m,mm}"
    end

    s.subspec 'NONE' do |none|
        none.dependency 'ScanbotSDKNativeWrapper', NativeWrapperVersion
        none.ios.vendored_frameworks = 'ScanbotSDK.framework', 'ScanbotSDKNativeWrapper.framework'
        none.source_files = "ios/**/*.{h,m,mm}"
    end

    s.default_subspec = 'NONE'
    s.static_framework = true
end
