package io.scanbot.sdk.reactnative.components.barcode_scanner_view

import com.facebook.react.bridge.Arguments
import com.facebook.react.bridge.WritableMap
import com.facebook.react.uimanager.events.Event
import io.scanbot.sdk.reactnative.extensions.toWritableMap
import io.scanbot.sdk.barcode.entity.BarcodeItem
import io.scanbot.sdk.barcode.entity.BarcodeScanningResult
import io.scanbot.sdk_wrapper.SBWrapper
import io.scanbot.sdk_wrapper.barcode.results.SBLegacyBarcodeResultField
import io.scanbot.sdk_wrapper.barcode.results.SBLegacyBarcodeScannerResult
import org.json.JSONObject

interface BaseEvent {
    val eventName: String
    fun parseData(): WritableMap
}

class ComponentEvent(private val baseEvent: BaseEvent, surfaceId: Int, viewTag: Int) :
    Event<ComponentEvent>(surfaceId, viewTag) {

    override fun getEventData(): WritableMap {
        return baseEvent.parseData()
    }

    override fun getEventName(): String {
        return baseEvent.eventName
    }

    override fun canCoalesce(): Boolean {
        return false
    }
}

class BarcodeScannerResultEvent(private val barcodeResult: BarcodeScanningResult) : BaseEvent {

    companion object {
        const val NAME = "barcodeScannerResult"
    }

    override val eventName = NAME

    override fun parseData(): WritableMap {
        return Arguments.createMap().apply {
            putMap(
                "result", JSONObject(
                    SBWrapper.gson.toJson(
                        SBLegacyBarcodeScannerResult.fromNativeBarcodeResult(barcodeResult)
                    )
                ).toWritableMap()
            )
        }
    }
}

class BarcodeSelectionResultEvent(private val barcodeItem: BarcodeItem) : BaseEvent {

    companion object {
        const val NAME = "selectBarcodeResult"
    }

    override val eventName = NAME

    override fun parseData(): WritableMap {
        return Arguments.createMap().apply {
            putMap(
                "result", JSONObject(
                    SBWrapper.gson.toJson(
                        SBLegacyBarcodeResultField.fromNativeBarcodeResult(barcodeItem)
                    )
                ).toWritableMap()
            )
        }
    }
}
