"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DocumentScannerScreens = void 0;
var _CameraScreenConfiguration = require("../document/CameraScreenConfiguration");
var _CroppingScreenConfiguration = require("../document/CroppingScreenConfiguration");
var _utils = require("../../utils");
var _ReorderPagesScreenConfiguration = require("../document/ReorderPagesScreenConfiguration");
var _ReviewScreenConfiguration = require("../document/ReviewScreenConfiguration");
/**
Configuration of the document scanner sub-screens.
*/
class DocumentScannerScreens extends _utils.PartiallyConstructible {
  /**
    Configuration of the screen for scanning the pages with the camera.
    */
  camera = new _CameraScreenConfiguration.CameraScreenConfiguration({});
  /**
    Configuration of the screen for reviewing the scanned pages.
    */
  review = new _ReviewScreenConfiguration.ReviewScreenConfiguration({});
  /**
    Configuration of the screen for cropping the scanned pages.
    */
  cropping = new _CroppingScreenConfiguration.CroppingScreenConfiguration({});
  /**
    Configuration of the screen for reordering the scanned pages.
    */
  reorderPages = new _ReorderPagesScreenConfiguration.ReorderPagesScreenConfiguration({});

  /** @param source {@displayType `DeepPartial<DocumentScannerScreens>`} */
  constructor(source = {}) {
    super();
    if (source.camera !== undefined) {
      this.camera = new _CameraScreenConfiguration.CameraScreenConfiguration(source.camera);
    }
    if (source.review !== undefined) {
      this.review = new _ReviewScreenConfiguration.ReviewScreenConfiguration(source.review);
    }
    if (source.cropping !== undefined) {
      this.cropping = new _CroppingScreenConfiguration.CroppingScreenConfiguration(source.cropping);
    }
    if (source.reorderPages !== undefined) {
      this.reorderPages = new _ReorderPagesScreenConfiguration.ReorderPagesScreenConfiguration(source.reorderPages);
    }
  }
}
exports.DocumentScannerScreens = DocumentScannerScreens;
//# sourceMappingURL=DocumentScannerScreens.js.map