import { CameraScreenConfiguration } from '../document/CameraScreenConfiguration';
import { CroppingScreenConfiguration } from '../document/CroppingScreenConfiguration';
import { PartiallyConstructible } from '../../utils';
import { ReorderPagesScreenConfiguration } from '../document/ReorderPagesScreenConfiguration';
import { ReviewScreenConfiguration } from '../document/ReviewScreenConfiguration';
/**
Configuration of the document scanner sub-screens.
*/
export class DocumentScannerScreens extends PartiallyConstructible {
  /**
    Configuration of the screen for scanning the pages with the camera.
    */
  camera = new CameraScreenConfiguration({});
  /**
    Configuration of the screen for reviewing the scanned pages.
    */
  review = new ReviewScreenConfiguration({});
  /**
    Configuration of the screen for cropping the scanned pages.
    */
  cropping = new CroppingScreenConfiguration({});
  /**
    Configuration of the screen for reordering the scanned pages.
    */
  reorderPages = new ReorderPagesScreenConfiguration({});

  /** @param source {@displayType `DeepPartial<DocumentScannerScreens>`} */
  constructor(source = {}) {
    super();
    if (source.camera !== undefined) {
      this.camera = new CameraScreenConfiguration(source.camera);
    }
    if (source.review !== undefined) {
      this.review = new ReviewScreenConfiguration(source.review);
    }
    if (source.cropping !== undefined) {
      this.cropping = new CroppingScreenConfiguration(source.cropping);
    }
    if (source.reorderPages !== undefined) {
      this.reorderPages = new ReorderPagesScreenConfiguration(source.reorderPages);
    }
  }
}
//# sourceMappingURL=DocumentScannerScreens.js.map