import { ParametricFilter } from '../document/ParametricFilters';
import { DeepPartial, PartiallyConstructible, Point } from '../utils';
import { DocumentDetectionStatus } from '../document/DocumentDetectionStatus';
import { DocumentQuality } from '../document/DocumentQuality';
import { PageImageSource } from '../document/PageImageSource';
/**
The result of the health insurance card recognition
*/
export declare class PageData extends PartiallyConstructible {
    /**
      The unique identifier of the page
      */
    readonly uuid: string;
    /**
      The list of filters applied to the page
      */
    readonly filters: ParametricFilter[] | null;
    /**
      The polygon of the page
      */
    readonly polygon: Point[];
    /**
      The detection status of the page
      */
    readonly documentDetectionStatus: DocumentDetectionStatus | null;
    /**
      The quality score of the page
      */
    readonly documentQuality: DocumentQuality | null;
    /**
      The source of the page image
      */
    readonly source: PageImageSource | null;
    /**
      The URI of the original image
      */
    readonly originalImageURI: string;
    /**
      The URI of the document image
      */
    readonly documentImageURI: string | null;
    /**
      The URI of the unfiltered document image
      */
    readonly unfilteredDocumentImageURI: string | null;
    /**
      The URI of the document image preview
      */
    readonly documentImagePreviewURI: string | null;
    /** @param source {@displayType `DeepPartial<PageData>`} */
    constructor(source?: DeepPartial<PageData>);
}
//# sourceMappingURL=PageData.d.ts.map