import { BarcodeItemMapper } from '../BarcodeItemMapper';
import { ButtonConfiguration } from '../common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils';
import { StyledText } from '../common/Common';
/**
Configuration of the the mapper's error dialog.
*/
export declare class BarcodeItemErrorState extends PartiallyConstructible {
    /**
      Title displayed above the error message.
      */
    title: StyledText;
    /**
      Error message.
      */
    subtitle: StyledText;
    /**
      Configuration of the retry button.
      */
    retryButton: ButtonConfiguration;
    /**
      Configuration of the cancel button.
      */
    cancelButton: ButtonConfiguration;
    /** @param source {@displayType `DeepPartial<BarcodeItemErrorState>`} */
    constructor(source?: DeepPartial<BarcodeItemErrorState>);
}
/**
Format of the mapped barcode data.
*/
export declare class BarcodeMappedData extends PartiallyConstructible {
    /**
      Title of the barcode.
      */
    title: string;
    /**
      Subtitle of the barcode.
      */
    subtitle: string;
    /**
      Image of the barcode.
      */
    barcodeImage: string;
    /**
      Use this key to display the original barcode image
      */
    static readonly barcodeImageKey = "BARCODE_IMAGE";
    /** @param source {@displayType `DeepPartial<BarcodeMappedData>`} */
    constructor(source?: DeepPartial<BarcodeMappedData>);
}
/**
Configuration of the barcode data mapping.
*/
export declare class BarcodeInfoMapping extends PartiallyConstructible {
    /**
      Callback to map the barcode data to the data of the corresponding product.
      */
    barcodeItemMapper: BarcodeItemMapper | null;
    /**
      Background color of the barcode info dialog.
      Default is "?sbColorSurface"
      */
    sheetColor: string;
    /**
      Color of the divider and separator lines in the barcode info dialog.
      Default is "?sbColorOutline"
      */
    dividerColor: string;
    /**
      Background color of the overlay surrounding the barcode mapping error dialog.
      Default is "?sbColorModalOverlay"
      */
    modalOverlayColor: string;
    /**
      Text being displayed while a barcode is being mapped.
      */
    loadingMessage: StyledText;
    /**
      Configuration of the error state displayed when processing a barcode fails.
      */
    errorState: BarcodeItemErrorState;
    /** @param source {@displayType `DeepPartial<BarcodeInfoMapping>`} */
    constructor(source?: DeepPartial<BarcodeInfoMapping>);
}
//# sourceMappingURL=BarcodeInfoMapping.d.ts.map