import { ArOverlayFindAndPickConfiguration } from '../barcode/ArTrackingOverlayConfiguration';
import { DeepPartial, PartiallyConstructible } from '../../utils';
import { ManualCountEditDialog } from '../barcode/MultipleScanningModeUseCase';
import { ScanbotAlertDialog } from '../common/ScanbotAlertDialog';
import { SheetContent } from '../barcode/MultipleScanningModeUseCase';
import { Sheet } from '../barcode/MultipleScanningModeUseCase';
/**
Configuration of the barcode to find and scan.
*/
export declare class ExpectedBarcode extends PartiallyConstructible {
    /**
      Value of the barcode to find. If not set, any barcode value will be accepted.
      */
    barcodeValue: string;
    /**
      Title of the barcode to find.
      */
    title: string | null;
    /**
      Image of the barcode to find.
      */
    image: string | null;
    /**
      Number of barcodes with given symbology/value required to scan.
      Default is 1
      */
    count: number;
    /**
     Use this key to display the original barcode image
     */
    static readonly barcodeImageKey = "BARCODE_IMAGE";
    /** @param source {@displayType `DeepPartial<ExpectedBarcode>`} */
    constructor(source?: DeepPartial<ExpectedBarcode>);
}
/**
Configuration of the Find and Pick barcode scanning mode.
*/
export declare class FindAndPickScanningMode extends PartiallyConstructible {
    readonly _type: 'FindAndPickScanningMode';
    /**
      Color of the selected barcode.
      Default is "?sbColorPositive"
      */
    scanningCompletedColor: string;
    /**
      Color of the partially scanned barcode.
      Default is "?sbColorWarning"
      */
    scanningPartiallyColor: string;
    /**
      Color of the not scanned barcode .
      Default is "?sbColorOutline"
      */
    scanningNotScannedColor: string;
    /**
      If the user is allowed to finish the scanning process without scanning all the expected barcodes.
      Default is false
      */
    allowPartialScan: boolean;
    /**
      List of barcodes that the user has to find and scan.
      */
    expectedBarcodes: ExpectedBarcode[];
    /**
      Time interval in milliseconds before a barcode is counted again. 0 = no delay. The default value is 1000.
      Default is 1000
      */
    countingRepeatDelay: number;
    /**
      Configuration of the preview mode for the barcodes required to be found and scanned.
      */
    sheet: Sheet;
    /**
      Configuration of the list of barcodes required to be found and scanned.
      */
    sheetContent: SheetContent;
    /**
      Configuration of the dialog to manually edit the barcode count.
      */
    manualCountEditDialog: ManualCountEditDialog;
    /**
      Configuration of the AR overlay.
      */
    arOverlay: ArOverlayFindAndPickConfiguration;
    /**
      If the partial scanned alert dialog is enabled.
      Default is true
      */
    partialScannedAlertDialogEnabled: boolean;
    /**
      Configuration of the partial scanned alert dialog.
      */
    partialScannedAlertDialog: ScanbotAlertDialog;
    /**
      If the confirmation alert dialog is enabled.
      Default is false
      */
    confirmationAlertDialogEnabled: boolean;
    /**
      Configuration of the confirmation alert dialog.
      */
    confirmationAlertDialog: ScanbotAlertDialog;
    /** @param source {@displayType `DeepPartial<FindAndPickScanningMode>`} */
    constructor(source?: DeepPartial<FindAndPickScanningMode>);
}
//# sourceMappingURL=FindAndPickScanningModeUseCase.d.ts.map