import { ButtonConfiguration } from '../common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils';
import { StyledText } from '../common/Common';
/**
Configuration of the top bar's appearance.
*/
export declare class TopBarConfiguration extends PartiallyConstructible {
    /**
      Appearance of the top bar's title.
      */
    title: StyledText;
    /**
      The visual mode used for the top bar.
      Default is SOLID
      */
    mode: TopBarMode;
    /**
      The visual mode used for the status bar icons.
      Default is LIGHT
      */
    statusBarMode: StatusBarMode;
    /**
      The background color of the top bar to be used when the visual mode is specified as SOLID. Otherwise ignored.
      Default is "?sbColorPrimary"
      */
    backgroundColor: string;
    /**
      Configuration of the 'cancel' button's appearance.
      */
    cancelButton: ButtonConfiguration;
    /** @param source {@displayType `DeepPartial<TopBarConfiguration>`} */
    constructor(source?: DeepPartial<TopBarConfiguration>);
}
/**
The visual mode used for the status bar icons.

- `DARK`:
   Display all icons in the status bar in black.
- `LIGHT`:
   Display all icons in the status bar in white.
- `HIDDEN`:
   Hide the status bar icons.
*/
export type StatusBarMode = 'DARK' | 'LIGHT' | 'HIDDEN';
/**
The visual mode used for the top bar.

- `SOLID`:
   Display the top bar with a background color or with transparency.
- `GRADIENT`:
   Display the top bar with a gradient background color or a gradient with transparency. The buttons will still be visible.
- `HIDDEN`:
   Hide the top bar completely.
*/
export type TopBarMode = 'SOLID' | 'GRADIENT' | 'HIDDEN';
//# sourceMappingURL=TopBarConfiguration.d.ts.map