import { AspectRatio } from '../common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils';
/**
Configuration of the scanning interface's viewfinder, serving as guidance to the user.
*/
export declare class ViewFinderConfiguration extends PartiallyConstructible {
    /**
      Determines whether the viewfinder is visible or not.
      Default is true
      */
    visible: boolean;
    /**
      The visual appearance of the viewfinder.
      */
    style: FinderStyle;
    /**
      The color of the viewfinder overlay.
      Default is "?sbColorSurfaceLow"
      */
    overlayColor: string;
    /**
      The viewfinder's aspect ratio.
      */
    aspectRatio: AspectRatio;
    /** @param source {@displayType `DeepPartial<ViewFinderConfiguration>`} */
    constructor(source?: DeepPartial<ViewFinderConfiguration>);
}
export type FinderStyle = FinderCorneredStyle | FinderStrokedStyle;
/**
A variant of the viewfinder displaying only the four corners of the scanning area.
*/
export declare class FinderCorneredStyle extends PartiallyConstructible {
    readonly _type: 'FinderCorneredStyle';
    /**
      The color of the viewfinder corner's outlines.
      Default is "#FFFFFFFF"
      */
    strokeColor: string;
    /**
      The width of the viewfinder corner's outlines.
      Default is 3.0
      */
    strokeWidth: number;
    /**
      The radius of the viewfinder's corners.
      Default is 10.0
      */
    cornerRadius: number;
    /** @param source {@displayType `DeepPartial<FinderCorneredStyle>`} */
    constructor(source?: DeepPartial<FinderCorneredStyle>);
}
/**
A variant of the viewfinder displaying a full outline of the scanning area.
*/
export declare class FinderStrokedStyle extends PartiallyConstructible {
    readonly _type: 'FinderStrokedStyle';
    /**
      The color of the viewfinder corner's outlines.
      Default is "#FFFFFFFF"
      */
    strokeColor: string;
    /**
      The width of the viewfinder corner's outlines.
      Default is 3.0
      */
    strokeWidth: number;
    /**
      The radius of the viewfinder's corners.
      Default is 10.0
      */
    cornerRadius: number;
    /** @param source {@displayType `DeepPartial<FinderStrokedStyle>`} */
    constructor(source?: DeepPartial<FinderStrokedStyle>);
}
//# sourceMappingURL=ViewFinderConfiguration.d.ts.map