import { BarButtonConfiguration } from '../common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils';
import { DocumentQuality } from '../../document/DocumentQuality';
import { IconUserGuidanceConfiguration } from '../common/UserGuidanceConfiguration';
/**
Determines, after each page is snapped, whether the acknowledgment screen should be displayed or not.

- `BAD_QUALITY`:
   The acknowledgement screen will only be shown when the quality of a scanned page is unacceptable. The quality threshold is determined by the `minimumQuality` parameter.
- `ALWAYS`:
   The acknowledgement screen will always be shown after each snap, regardless of the scanned page's quality.
- `NONE`:
   The acknowledgement screen will be disabled, in effect never shown.
*/
export type AcknowledgementMode = 'BAD_QUALITY' | 'ALWAYS' | 'NONE';
/**
Configuration of the bottom bar for the acknowledgement screen.
*/
export declare class AcknowledgementBottomBar extends PartiallyConstructible {
    /**
      Configuration of the 'retake' button.
      */
    retakeButton: BarButtonConfiguration;
    /**
      Configuration of the 'accept' button, when the quality of the scanned page is acceptable.
      */
    acceptWhenOkButton: BarButtonConfiguration;
    /**
      Configuration of the 'accept' button, when the quality of the scanned page is unacceptable.
      */
    acceptWhenNotOkButton: BarButtonConfiguration;
    /** @param source {@displayType `DeepPartial<AcknowledgementBottomBar>`} */
    constructor(source?: DeepPartial<AcknowledgementBottomBar>);
}
/**
Configuration of the acknowledgement screen.
*/
export declare class AcknowledgementScreenConfiguration extends PartiallyConstructible {
    /**
      The minimum quality of a scanned page to be deemed acceptable. Used in conjunction with the acknowledgement mode.
      Default is POOR
      */
    minimumQuality: DocumentQuality;
    /**
      Determines, after each page is snapped, whether the acknowledgment screen should be displayed or not.
      Default is ALWAYS
      */
    acknowledgementMode: AcknowledgementMode;
    /**
      Configuration of the hint that explains that the quality of the scanned page is unacceptable.
      */
    badImageHint: IconUserGuidanceConfiguration;
    /**
      The background color of the acknowledgement screen.
      Default is "?sbColorOutline"
      */
    backgroundColor: string;
    /**
      Configuration of the bottom bar for the acknowledgement screen.
      */
    bottomBar: AcknowledgementBottomBar;
    /** @param source {@displayType `DeepPartial<AcknowledgementScreenConfiguration>`} */
    constructor(source?: DeepPartial<AcknowledgementScreenConfiguration>);
}
//# sourceMappingURL=AcknowledgementScreenConfiguration.d.ts.map