import { CroppingScreenConfiguration } from '../document/CroppingScreenConfiguration';
import { CroppingTextLocalization } from '../document/CroppingTextLocalization';
import { DeepPartial, PartiallyConstructible } from '../../utils';
import { DocumentAnalysisMode } from '../document/DocumentScannerOutputSettings';
import { NavigationBarMode } from '../common/NavigationBarConfiguration';
import { OrientationLockMode } from '../common/Common';
import { Palette } from '../common/Common';
import { StatusBarMode } from '../common/TopBarConfiguration';
/**
Configuration of the general appearance for the cropping screen.
*/
export declare class CroppingAppearanceConfiguration extends PartiallyConstructible {
    /**
      Determines the visual mode used for the status bar icons.
      Default is LIGHT
      */
    statusBarMode: StatusBarMode;
    /**
      Determines the visual mode used for the navigation bar icons. Android only.
      Default is LIGHT
      */
    navigationBarMode: NavigationBarMode;
    /**
      The background color of the top bar. Only applicable when the visual mode is specified as 'SOLID', otherwise ignored.
      Default is "?sbColorPrimary"
      */
    topBarBackgroundColor: string;
    /**
      The background color of the bottom bar.
      Default is "?sbColorPrimary"
      */
    bottomBarBackgroundColor: string;
    /**
      Which mode to use when orientation should be locked to landscape or portrait.
      Default is NONE
      */
    orientationLockMode: OrientationLockMode;
    /** @param source {@displayType `DeepPartial<CroppingAppearanceConfiguration>`} */
    constructor(source?: DeepPartial<CroppingAppearanceConfiguration>);
}
/**
Configuration of the standalone cropping screen.
*/
export declare class CroppingConfiguration extends PartiallyConstructible {
    /**
      Version number of the configuration object.
      Default is "1.0"
      */
    version: string;
    /**
      The configuration object should be applied for this screen.
      Default is "CroppingConfiguration"
      */
    screen: string;
    /**
      Define the screen's base color values from which other colors are derived.
      */
    palette: Palette;
    /**
      The UUID of the document to be cropped.
      */
    documentUuid: string;
    /**
      The UUID of the page of the document to be cropped.
      */
    pageUuid: string;
    /**
      Configuration of all the strings for the standalone cropping screen.
      */
    localization: CroppingTextLocalization;
    /**
      Configuration of the general appearance for the cropping screen.
      */
    appearance: CroppingAppearanceConfiguration;
    /**
      Configuration of the cropping screen.
      */
    cropping: CroppingScreenConfiguration;
    /**
      Determines if the quality analysis for the acknowledgement mode will run on the filtered or the unfiltered image.
      Default is UNFILTERED_DOCUMENT
      */
    documentAnalysisMode: DocumentAnalysisMode;
    /** @param source {@displayType `DeepPartial<CroppingConfiguration>`} */
    constructor(source?: DeepPartial<CroppingConfiguration>);
}
//# sourceMappingURL=CroppingConfiguration.d.ts.map