import { DeepPartial, PartiallyConstructible } from '../../utils';
/**
Configuration of all the strings for the standalone cropping screen.
*/
export declare class DocumentScannerTextLocalization extends PartiallyConstructible {
    /**
      The title of the camera permission dialog.
      Default is "Camera permission denied!"
      */
    cameraPermissionEnableCameraTitle: string;
    /**
      The explanation text of the camera permission dialog.
      Default is "Please allow the usage of the camera to start the scanning process."
      */
    cameraPermissionEnableCameraExplanation: string;
    /**
      The 'enable' button title of the camera permission dialog.
      Default is "Grant permission"
      */
    cameraPermissionEnableCameraButton: string;
    /**
      The 'close' button title of the camera permission dialog.
      Default is "Close"
      */
    cameraPermissionCloseButton: string;
    /**
      The 'cancel' button title, located in the top bar of the camera screen and the reorder pages screen.
      Default is "Cancel"
      */
    cameraTopBarCancelButtonTitle: string;
    /**
      The title of the camera screen, located in the top bar.
      Default is "Scan Document"
      */
    cameraTopBarTitle: string;
    /**
      The text for the static user guidance, located just below the top bar of the camera screen.
      Default is "Scan each page of your document."
      */
    cameraTopGuidance: string;
    /**
      The user guidance text that is initially displayed, before a document is detected.
      Default is "Please hold your device over a document."
      */
    cameraUserGuidanceStart: string;
    /**
      The user guidance text displayed when no document is found.
      Default is "No document found"
      */
    cameraUserGuidanceNoDocumentFound: string;
    /**
      The user guidance text displayed when a landscape document is detected when the camera is in portrait mode (and vice versa).
      Default is "Bad aspect ratio"
      */
    cameraUserGuidanceBadAspectRatio: string;
    /**
      The user guidance text displayed when the document pitch/skew angle is unacceptable.
      Default is "Bad angles"
      */
    cameraUserGuidanceBadAngles: string;
    /**
      The user guidance text displayed when the background is too noisy.
      Default is "Its too noisy. Try another background for the document"
      */
    cameraUserGuidanceTooNoisy: string;
    /**
      The user guidance text displayed when the document is not centered in the finder view.
      Default is "Document is off center"
      */
    cameraUserGuidanceTextHintOffCenter: string;
    /**
      The user guidance text displayed when the document is too far from camera.
      Default is "Document is too small. Move camera closer."
      */
    cameraUserGuidanceTooSmall: string;
    /**
      The user guidance text displayed when it is too dark to capture an adequate image.
      Default is "Its too dark. Add more light."
      */
    cameraUserGuidanceTooDark: string;
    /**
      The user guidance text displayed when the device is in energy saving mode. iOS only.
      Default is "Energy save mode is on"
      */
    cameraUserGuidanceEnergySaveMode: string;
    /**
      The user guidance text displayed when the document is ready to be captured in 'auto snapping' mode.
      Default is "Hold still capturing..."
      */
    cameraUserGuidanceReadyToCapture: string;
    /**
      The user guidance text displayed when the document is ready to be captured in 'manual snapping' mode.
      Default is "Ready to capture!"
      */
    cameraUserGuidanceReadyToCaptureManual: string;
    /**
      The 'import image' button title, located in the bottom bar of the camera screen.
      Default is "Import"
      */
    cameraImportButtonTitle: string;
    /**
      The 'flashlight on' button title, located in the bottom bar of the camera screen.
      Default is "On"
      */
    cameraTorchOnButtonTitle: string;
    /**
      The 'flashlight off' button title, located in the bottom bar of the camera screen.
      Default is "Off"
      */
    cameraTorchOffButtonTitle: string;
    /**
      The 'auto snapping' mode button title, located in the bottom bar of the camera screen.
      Default is "Auto"
      */
    cameraAutoSnapButtonTitle: string;
    /**
      The 'manual snapping' mode button title, located in the bottom bar of the camera screen.
      Default is "Manual"
      */
    cameraManualSnapButtonTitle: string;
    /**
      The 'preview' button title, located in the bottom bar of the camera screen. '%d' denotes the total number of captured pages.
      Default is "%d Pages"
      */
    cameraPreviewButtonTitle: string;
    /**
      The 'done' button title of the introduction screen, located in the top bar.
      Default is "Done"
      */
    cameraIntroDoneButton: string;
    /**
      The title of the introduction screen, located in the top bar.
      Default is "How to scan a document"
      */
    cameraIntroTitle: string;
    /**
      The subtitle of the introduction screen.
      Default is "Follow the steps below to create a high-quality document scan"
      */
    cameraIntroSubtitle: string;
    /**
      The first scanning step text of the introduction screen.
      Default is "1. Place your document on a flat surface."
      */
    cameraIntroItem1: string;
    /**
      The second scanning step text of the introduction screen.
      Default is "2. Hold your phone above the document."
      */
    cameraIntroItem2: string;
    /**
      The third scanning step text of the introduction screen.
      Default is "3. Follow the on-screen guidance to find the optimal position."
      */
    cameraIntroItem3: string;
    /**
      The fourth scanning step text of the introduction screen.
      Default is "4. Once you reach the optimal position, you can manually scan the document or let the app scan it automatically."
      */
    cameraIntroItem4: string;
    /**
      The progress overlay title that is displayed on the camera screen during processing.
      Default is "Please wait..."
      */
    cameraProgressOverlayTitle: string;
    /**
      The title of the cancel camera screen alert dialog.
      Default is "Cancel?"
      */
    cameraCancelAlertTitle: string;
    /**
      The subtitle of the cancel camera screen alert dialog.
      Default is "Canceling will delete all the pages scanned so far. Are you sure you want to cancel?"
      */
    cameraCancelAlertSubtitle: string;
    /**
      The 'no' button title of the cancel camera screen alert dialog.
      Default is "No"
      */
    cameraCancelNoButtonTitle: string;
    /**
      The 'yes' button title of the cancel camera screen alert dialog.
      Default is "Yes, Cancel"
      */
    cameraCancelYesButtonTitle: string;
    /**
      The title of the page limit reached alert dialog.
      Default is "You reached the limit!"
      */
    cameraLimitReachedAlertTitle: string;
    /**
      The subtitle of the page limit reached alert dialog.
      Default is "You have scanned the maximum number of pages and cannot add any more. Please delete at least one page to perform a new scan."
      */
    cameraLimitReachedAlertSubtitle: string;
    /**
      The 'OK' button title of the page limit reached alert dialog.
      Default is "Ok"
      */
    cameraLimitReachedOkButtonTitle: string;
    /**
      The hint text of the acknowledgement screen explaining that the quality of the scanned page is unacceptable.
      Default is "The quality of your scan does not seem sufficient."
      */
    acknowledgementScreenBadDocumentHint: string;
    /**
      The 'retake' button title of the acknowledgement screen.
      Default is "Retake"
      */
    acknowledgementRetakeButtonTitle: string;
    /**
      The 'accept' button title of the acknowledgement screen.
      Default is "Use Scan"
      */
    acknowledgementAcceptButtonTitle: string;
    /**
      The title of the review screen, located in the top bar. '%d' denotes the total number of captured pages.
      Default is "Review (%d)"
      */
    reviewScreenTitle: string;
    /**
      The 'back' button title, located in the top bar of the review screen.
      Default is "Back"
      */
    reviewTopBarBackButtonTitle: string;
    /**
      The page count label text. The first occurrence of '%d' denotes the current page number, while the second occurrence of '%d' denotes the total number of captured pages.
      Default is "Page %d/%d"
      */
    reviewScreenPageCount: string;
    /**
      The 'add' button title, located in the bottom bar of the review screen.
      Default is "Add"
      */
    reviewScreenAddButtonTitle: string;
    /**
      The 'retake' button title, located in the bottom bar of the review screen.
      Default is "Retake"
      */
    reviewScreenRetakeButtonTitle: string;
    /**
      The 'crop' button title, located in the bottom bar of the review screen.
      Default is "Crop"
      */
    reviewScreenCropButtonTitle: string;
    /**
      The 'rotate' button title, located in the bottom bar of the review screen.
      Default is "Rotate"
      */
    reviewScreenRotateButtonTitle: string;
    /**
      The 'delete' button title, located in the bottom bar of the review screen.
      Default is "Delete"
      */
    reviewScreenDeleteButtonTitle: string;
    /**
      The 'submit' button title, located in the bottom bar of the review screen.
      Default is "Submit"
      */
    reviewScreenSubmitButtonTitle: string;
    /**
      The 'delete all' menu button title, accessed via the 'more' button of the review screen.
      Default is "Delete all"
      */
    reviewScreenDeleteAllButtonTitle: string;
    /**
      The 'reorder pages' menu button title, accessed via the 'more' button of the review screen.
      Default is "Reorder pages"
      */
    reviewScreenReorderPagesButtonTitle: string;
    /**
      The 'close' button title of the zoom overlay for the review screen.
      Default is "Close"
      */
    zoomOverlayCancelButtonText: string;
    /**
      The title of the delete page alert dialog for the review screen.
      Default is "Delete page?"
      */
    reviewDeletePageAlertTitle: string;
    /**
      The title of the delete all pages alert dialog for the review screen.
      Default is "Delete all?"
      */
    reviewDeleteAllPagesAlertTitle: string;
    /**
      The subtitle of the delete page alert dialog for the review screen.
      Default is "Are you sure you want to delete the page?"
      */
    reviewDeletePageAlertSubTitle: string;
    /**
      The subtitle of the delete all pages alert dialog for the review screen.
      Default is "Are you sure you want to delete all pages?"
      */
    reviewDeleteAllPagesAlertSubtitle: string;
    /**
      The 'confirm' button title of the delete page alert dialog for the review screen.
      Default is "Yes, Delete"
      */
    reviewDeletePageAlertConfirmButtonTitle: string;
    /**
      The 'confirm' button title of the delete all pages alert dialog for the review screen.
      Default is "Yes, Delete all"
      */
    reviewDeleteAllPagesAlertDeleteButtonTitle: string;
    /**
      The 'delete and retake' button title of the delete page alert dialog for the review screen.
      Default is "Delete and Retake"
      */
    reviewDeletePageAlertDeleteRetakeButtonTitle: string;
    /**
      The 'cancel' button title of the delete page alert dialog for the review screen.
      Default is "Cancel"
      */
    reviewDeletePageAlertCancelButtonTitle: string;
    /**
      The 'cancel' button title of the delete all pages alert dialog for the review screen.
      Default is "Cancel"
      */
    reviewDeleteAllPagesAlertCancelButtonTitle: string;
    /**
      The title of the reorder pages screen, located in the top bar.
      Default is "Reorder Pages"
      */
    reorderPageTitle: string;
    /**
      The text for the static user guidance, located just below the top bar of the reorder pages screen.
      Default is "Drag pages to reorder"
      */
    reorderPageGuidanceTitle: string;
    /**
      The title below each page object of the reorder pages screen. '%d' denotes the current page number.
      Default is "%d"
      */
    reorderPageText: string;
    /**
      The 'confirm' button title, located in the top bar of the reorder pages screen.
      Default is "Done"
      */
    reorderTopBarConfirmButtonTitle: string;
    /**
      The 'cancel' button title, located in the top bar of the reorder pages screen.
      Default is "Cancel"
      */
    reorderTopBarCancelButtonTitle: string;
    /**
      The 'confirm' button title, located in the top bar of the cropping screen.
      Default is "Done"
      */
    croppingTopBarConfirmButtonTitle: string;
    /**
      The 'cancel' button title, located in the top bar of the cropping screen.
      Default is "Cancel"
      */
    croppingTopBarCancelButtonTitle: string;
    /**
      The 'detect document' button title, located in the bottom bar of the cropping screen.
      Default is "Detect"
      */
    croppingDetectButtonTitle: string;
    /**
      The 'rotate page' button title, located in the bottom bar of the cropping screen.
      Default is "Rotate"
      */
    croppingRotateButtonTitle: string;
    /**
      The 'reset detection' button title, located in the bottom bar of the cropping screen.
      Default is "Reset"
      */
    croppingResetButtonTitle: string;
    /**
      The title of the cropping screen, located in the top bar.
      Default is "Crop"
      */
    croppingScreenTitle: string;
    /**
      The accessibility hint for the 'enable' button of the camera permission dialog.
      Default is "Tap to grant camera permission"
      */
    accessibilityDescriptionCameraPermissionEnableCameraButton: string;
    /**
      The accessibility hint for the 'close' button of the camera permission dialog.
      Default is "Close screen without granting permission"
      */
    accessibilityDescriptionCameraPermissionCloseButton: string;
    /**
      The accessibility hint for the 'introduction' button, located in the top bar of the camera screen.
      Default is "Tap to open introduction screen"
      */
    accessibilityDescriptionCameraTopBarIntroButton: string;
    /**
      The accessibility hint for the 'cancel' button, located in the top bar of the camera screen.
      Default is "Tap to close scanner screen"
      */
    accessibilityDescriptionCameraTopBarCancelButton: string;
    /**
      The accessibility hint for the 'import image' button, located in the bottom bar of the camera screen.
      Default is "Tap to import image"
      */
    accessibilityDescriptionCameraImportButton: string;
    /**
      The accessibility hint for the 'flashlight on' button, located in the bottom bar of the camera screen.
      Default is "Tap to disable torch"
      */
    accessibilityDescriptionCameraTorchOnButton: string;
    /**
      The accessibility hint for the 'flashlight off' button, located in the bottom bar of the camera screen.
      Default is "Tap to enable torch"
      */
    accessibilityDescriptionCameraTorchOffButton: string;
    /**
      The accessibility hint for the 'shutter' button, located in the bottom bar of the camera screen.
      Default is "Tap to take image"
      */
    accessibilityDescriptionCameraShutterButton: string;
    /**
      The accessibility hint for the 'auto snapping' mode button, located in the bottom bar of the camera screen.
      Default is "Tap to enable manual snapping mode"
      */
    accessibilityDescriptionCameraAutoSnapButton: string;
    /**
      The accessibility hint for the 'manual snapping' mode button, located in the bottom bar of the camera screen.
      Default is "Tap to enable auto snapping mode"
      */
    accessibilityDescriptionCameraManualSnapButton: string;
    /**
      The accessibility hint for the 'preview' button, located in the bottom bar of the camera screen.
      Default is "Tap to preview scanned pages"
      */
    accessibilityDescriptionCameraPreviewButton: string;
    /**
      The accessibility hint for the 'done' button of the introduction screen.
      Default is "Tap to close introduction screen"
      */
    accessibilityDescriptionCameraIntroDoneButton: string;
    /**
      The accessibility hint for the 'retake' button of the acknowledgement screen.
      Default is "Tap to retake the image"
      */
    accessibilityDescriptionAcknowledgementRetakeButton: string;
    /**
      The accessibility hint for the 'accept' button of the acknowledgement screen.
      Default is "Tap to accept the image regardless of its quality"
      */
    accessibilityDescriptionAcknowledgementAcceptButton: string;
    /**
      The accessibility hint for the 'confirm' button, located in the top bar of the cropping screen.
      Default is "Tap to apply changes"
      */
    accessibilityDescriptionCroppingTopBarConfirmButton: string;
    /**
      The accessibility hint for the 'cancel' button, located in the top bar of the cropping screen.
      Default is "Tap to close screen without applying changes"
      */
    accessibilityDescriptionCroppingTopBarCancelButton: string;
    /**
      The accessibility hint for the 'detect document' button, located in the bottom bar of the cropping screen.
      Default is "Tap to detect document on the image"
      */
    accessibilityDescriptionCroppingDetectButton: string;
    /**
      The accessibility hint for the 'rotate page' button, located in the bottom bar of the cropping screen.
      Default is "Tap to rotate document"
      */
    accessibilityDescriptionCroppingRotateButton: string;
    /**
      The accessibility hint for the 'reset detection' button, located in the bottom bar of the cropping screen.
      Default is "Tap to reset document contour to whole image"
      */
    accessibilityDescriptionCroppingResetButton: string;
    /**
      The accessibility hint for the 'confirm' button, located in the top bar of the reorder pages screen.
      Default is "Tap to apply changes"
      */
    accessibilityDescriptionReorderTopBarConfirmButton: string;
    /**
      The accessibility hint for the 'cancel' button, located in the top bar of the reorder pages screen.
      Default is "Tap to close screen without applying changes"
      */
    accessibilityDescriptionReorderTopBarCancelButton: string;
    /**
      The accessibility hint for the 'next page' button of the review screen.
      Default is "Tap to switch to the new page"
      */
    accessibilityDescriptionReviewNextPageButton: string;
    /**
      The accessibility hint for the 'previous page' button of the review screen.
      Default is "Tap to switch to the previous page"
      */
    accessibilityDescriptionReviewPreviousPageButton: string;
    /**
      The accessibility hint for the 'add' button, located in the bottom bar of the review screen.
      Default is "Tap to Add new page"
      */
    accessibilityDescriptionReviewAddButton: string;
    /**
      The accessibility hint for the 'retake' button, located in the bottom bar of the review screen.
      Default is "Tap to Retake current selected page"
      */
    accessibilityDescriptionReviewRetakeButton: string;
    /**
      The accessibility hint for the 'crop' button, located in the bottom bar of the review screen.
      Default is "Tap to Crop selected page"
      */
    accessibilityDescriptionReviewCropButton: string;
    /**
      The accessibility hint for the 'rotate' button, located in the bottom bar of the review screen.
      Default is "Tap to Rotate selected page clockwise"
      */
    accessibilityDescriptionReviewRotateButton: string;
    /**
      The accessibility hint for the 'delete' button, located in the bottom bar of the review screen.
      Default is "Tap to Delete selected page"
      */
    accessibilityDescriptionReviewDeleteButton: string;
    /**
      The accessibility hint for the 'submit' button, located in the bottom bar of the review screen.
      Default is "Tap to Submit document"
      */
    accessibilityDescriptionReviewSubmitButton: string;
    /**
      The accessibility hint for the 'more' button, located in the top bar of the review screen.
      Default is "Tap to show additional options"
      */
    accessibilityDescriptionReviewMoreButton: string;
    /**
      The accessibility hint for the 'delete all' menu button, accessed via the 'more' button of the review screen.
      Default is "Tap to Delete all pages"
      */
    accessibilityDescriptionReviewDeleteAllButton: string;
    /**
      The accessibility hint for the 'reorder pages' menu button, accessed via the 'more' button of the review screen.
      Default is "Tap to Reorder pages"
      */
    accessibilityDescriptionReviewReorderPagesButton: string;
    /**
      The accessibility hint for the 'close' button of the zoom overlay for the review screen.
      Default is "Tap to Close zoom overlay"
      */
    accessibilityDescriptionZoomOverlayCancelButton: string;
    /**
      The accessibility hint for the 'zoom' button of the review screen.
      Default is "Tap to open zoom overlay for selected page"
      */
    accessibilityDescriptionReviewZoomButton: string;
    /**
      The accessibility hint for the 'back' button, located in the top bar of the review screen.
      Default is "Tap to Close review screen"
      */
    accessibilityDescriptionReviewTopBarBackButton: string;
    /**
      The accessibility hint for the 'confirm' button of the delete page alert dialog for the review screen.
      Default is "Tap to Delete page"
      */
    accessibilityDescriptionReviewDeletePageAlertConfirmButton: string;
    /**
      The accessibility hint for the 'confirm' button of the delete all pages alert dialog for the review screen.
      Default is "Tap to Delete all pages"
      */
    accessibilityDescriptionReviewDeleteAllPagesAlertDeleteButton: string;
    /**
      The accessibility hint for the 'delete and retake' button of the delete page alert dialog for the review screen.
      Default is "Tap to Delete page and Retake it"
      */
    accessibilityDescriptionReviewDeletePageAlertDeleteRetakeButton: string;
    /**
      The accessibility hint for the 'cancel' button of the delete page alert dialog for the review screen.
      Default is "Tap to Cancel operation"
      */
    accessibilityDescriptionReviewDeletePageAlertCancelButton: string;
    /**
      The accessibility hint for the 'cancel' button of the delete all pages alert dialog for the review screen.
      Default is "Tap to Cancel operation"
      */
    accessibilityDescriptionReviewDeleteAllPagesAlertCancelButton: string;
    /**
      The accessibility hint for the 'OK' button of the page limit reached alert dialog.
      Default is "Tap to close alert dialog"
      */
    accessibilityDescriptionCameraLimitReachedOkButton: string;
    /**
      The accessibility hint for the 'yes' button of the cancel camera screen alert dialog.
      Default is "Tap to cancel document"
      */
    accessibilityDescriptionCameraCancelYesButton: string;
    /**
      The accessibility hint for the 'no' button of the cancel camera screen alert dialog.
      Default is "Tap to close alert dialog"
      */
    accessibilityDescriptionCameraCancelNoButton: string;
    /** @param source {@displayType `DeepPartial<DocumentScannerTextLocalization>`} */
    constructor(source?: DeepPartial<DocumentScannerTextLocalization>);
}
//# sourceMappingURL=DocumentScannerTextLocalization.d.ts.map