import { BackgroundStyle } from '../common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils';
import { StyledText } from '../common/Common';
import { UserGuidanceVisibility } from '../document/DocumentScannerGuidanceVisibility';
/**
Configure the titles of the user guidance hints for different states.
*/
export declare class UserGuidanceStates extends PartiallyConstructible {
    /**
      The user guidance text displayed when no document is found.
      Default is "?cameraUserGuidanceNoDocumentFound"
      */
    noDocumentFound: string;
    /**
      The user guidance text displayed when a landscape document is detected when the camera is in portrait mode (and vice versa).
      Default is "?cameraUserGuidanceBadAspectRatio"
      */
    badAspectRatio: string;
    /**
      The user guidance text displayed when the document pitch/skew angle is unacceptable.
      Default is "?cameraUserGuidanceBadAngles"
      */
    badAngles: string;
    /**
      The user guidance text displayed when the document is not centered in the finder view.
      Default is "?cameraUserGuidanceTextHintOffCenter"
      */
    textHintOffCenter: string;
    /**
      The user guidance text displayed when the document is too far from camera.
      Default is "?cameraUserGuidanceTooSmall"
      */
    tooSmall: string;
    /**
      The user guidance text displayed when the background is too noisy.
      Default is "?cameraUserGuidanceTooNoisy"
      */
    tooNoisy: string;
    /**
      The user guidance text displayed when it is too dark to capture an adequate image.
      Default is "?cameraUserGuidanceTooDark"
      */
    tooDark: string;
    /**
      The user guidance text displayed when the device is in energy saving mode. iOS only.
      Default is "?cameraUserGuidanceEnergySaveMode"
      */
    energySaveMode: string;
    /**
      The user guidance text displayed when the document is ready to be captured in 'auto snapping' mode.
      Default is "?cameraUserGuidanceReadyToCapture"
      */
    readyToCapture: string;
    /**
      The user guidance text displayed when the document is being captured and user needs to hold the device still.
      Default is "?cameraUserGuidanceReadyToCapture"
      */
    capturing: string;
    /**
      The user guidance text displayed when the document is ready to be captured in 'manual snapping' mode.
      Default is "?cameraUserGuidanceReadyToCaptureManual"
      */
    captureManual: string;
    /** @param source {@displayType `DeepPartial<UserGuidanceStates>`} */
    constructor(source?: DeepPartial<UserGuidanceStates>);
}
/**
Configuration of the hints guiding users through the scanning process.
*/
export declare class DocumentScannerUserGuidance extends PartiallyConstructible {
    /**
      Determines when the user guidance hints should be visible.
      Default is ENABLED
      */
    visibility: UserGuidanceVisibility;
    /**
      Configure the text style for the user guidance hints.
      */
    title: StyledText;
    /**
      Configure the background style for the user guidance hints.
      */
    background: BackgroundStyle;
    /**
      Configure the titles of the user guidance hints for different states.
      */
    statesTitles: UserGuidanceStates;
    /** @param source {@displayType `DeepPartial<DocumentScannerUserGuidance>`} */
    constructor(source?: DeepPartial<DocumentScannerUserGuidance>);
}
//# sourceMappingURL=DocumentScannerUserGuidance.d.ts.map