import { DeepPartial, PartiallyConstructible } from '../../utils';
import { DocumentScannerOutputSettings } from '../document/DocumentScannerOutputSettings';
import { DocumentScannerScreens } from '../document/DocumentScannerScreens';
import { DocumentScannerTextLocalization } from '../document/DocumentScannerTextLocalization';
import { NavigationBarMode } from '../common/NavigationBarConfiguration';
import { OrientationLockMode } from '../common/Common';
import { Palette } from '../common/Common';
import { StatusBarMode } from '../common/TopBarConfiguration';
/**
Configuration of the general appearance.
*/
export declare class DocumentFlowAppearanceConfiguration extends PartiallyConstructible {
    /**
      Determines the visual mode used for the status bar icons.
      Default is LIGHT
      */
    statusBarMode: StatusBarMode;
    /**
      Determines the visual mode used for the navigation bar icons. Android only.
      Default is LIGHT
      */
    navigationBarMode: NavigationBarMode;
    /**
      The background color of the top bar. Only applicable when the visual mode is specified as 'SOLID', otherwise ignored.
      Default is "?sbColorPrimary"
      */
    topBarBackgroundColor: string;
    /**
      The background color of the bottom bar.
      Default is "?sbColorPrimary"
      */
    bottomBarBackgroundColor: string;
    /**
      Which mode to use when orientation should be locked to landscape or portrait.
      Default is NONE
      */
    orientationLockMode: OrientationLockMode;
    /** @param source {@displayType `DeepPartial<DocumentFlowAppearanceConfiguration>`} */
    constructor(source?: DeepPartial<DocumentFlowAppearanceConfiguration>);
}
/**
Configuration of the document scanner screen.
*/
export declare class DocumentScanningFlow extends PartiallyConstructible {
    /**
      Version number of the configuration object.
      Default is "1.0"
      */
    version: string;
    /**
      The configuration object should be applied for this screen.
      Default is "DocumentScanner"
      */
    screen: string;
    /**
      Define the screen's base color values from which other colors are derived.
      */
    palette: Palette;
    /**
      Configuration of all the strings for the document scanner screen.
      */
    localization: DocumentScannerTextLocalization;
    /**
      Configuration of the general appearance.
      */
    appearance: DocumentFlowAppearanceConfiguration;
    /**
      Configuration of the output settings.
      */
    outputSettings: DocumentScannerOutputSettings;
    /**
      Configuration of the document scanner sub-screens.
      */
    screens: DocumentScannerScreens;
    /**
      The UUID of the existing document to be edited.
      */
    documentUuid: string | null;
    /**
      Clean the existing pages from the scanning session.
      Default is true
      */
    cleanScanningSession: boolean;
    /** @param source {@displayType `DeepPartial<DocumentScanningFlow>`} */
    constructor(source?: DeepPartial<DocumentScanningFlow>);
}
//# sourceMappingURL=DocumentScanningFlow.d.ts.map