import { ButtonConfiguration } from '../common/Common';
import { DeepPartial, PartiallyConstructible } from '../../utils';
import { StyledText } from '../common/Common';
/**
An entry in the list of scanning steps of the introduction screen.
*/
export declare class IntroListEntry extends PartiallyConstructible {
    /**
      The image of the entry.
      */
    image: IntroImage;
    /**
      The text of the entry.
      */
    text: StyledText;
    /** @param source {@displayType `DeepPartial<IntroListEntry>`} */
    constructor(source?: DeepPartial<IntroListEntry>);
}
export type IntroImage = NoIntroImage | ReceiptsIntroImage | MedicalCertificateIntroImage | DocumentIntroImage | CheckIntroImage | IdCardIntroImage | CreditCardIntroImage | CustomImage;
/**
No image for the introduction screen.
*/
export declare class NoIntroImage extends PartiallyConstructible {
    readonly _type: 'NoIntroImage';
    /** @param source {@displayType `DeepPartial<NoIntroImage>`} */
    constructor(source?: DeepPartial<NoIntroImage>);
}
/**
The image for the introduction screen with a receipt template.
*/
export declare class ReceiptsIntroImage extends PartiallyConstructible {
    readonly _type: 'ReceiptsIntroImage';
    /** @param source {@displayType `DeepPartial<ReceiptsIntroImage>`} */
    constructor(source?: DeepPartial<ReceiptsIntroImage>);
}
/**
The image for the introduction screen with a medical certificate template.
*/
export declare class MedicalCertificateIntroImage extends PartiallyConstructible {
    readonly _type: 'MedicalCertificateIntroImage';
    /** @param source {@displayType `DeepPartial<MedicalCertificateIntroImage>`} */
    constructor(source?: DeepPartial<MedicalCertificateIntroImage>);
}
/**
The image for the introduction screen with a document template.
*/
export declare class DocumentIntroImage extends PartiallyConstructible {
    readonly _type: 'DocumentIntroImage';
    /** @param source {@displayType `DeepPartial<DocumentIntroImage>`} */
    constructor(source?: DeepPartial<DocumentIntroImage>);
}
/**
The image for the introduction screen with a check template.
*/
export declare class CheckIntroImage extends PartiallyConstructible {
    readonly _type: 'CheckIntroImage';
    /** @param source {@displayType `DeepPartial<CheckIntroImage>`} */
    constructor(source?: DeepPartial<CheckIntroImage>);
}
/**
The image for the introduction screen with an ID card template.
*/
export declare class IdCardIntroImage extends PartiallyConstructible {
    readonly _type: 'IdCardIntroImage';
    /** @param source {@displayType `DeepPartial<IdCardIntroImage>`} */
    constructor(source?: DeepPartial<IdCardIntroImage>);
}
/**
The image for the introduction screen with a credit card template.
*/
export declare class CreditCardIntroImage extends PartiallyConstructible {
    readonly _type: 'CreditCardIntroImage';
    /** @param source {@displayType `DeepPartial<CreditCardIntroImage>`} */
    constructor(source?: DeepPartial<CreditCardIntroImage>);
}
/**
A custom image for the introduction screen.
*/
export declare class CustomImage extends PartiallyConstructible {
    readonly _type: 'CustomImage';
    /**
      The web or file URI to the image.
      */
    uri: string;
    /** @param source {@displayType `DeepPartial<CustomImage>`} */
    constructor(source?: DeepPartial<CustomImage>);
}
/**
Configuration of the introduction screen for the document scanner.
*/
export declare class IntroductionScreenConfiguration extends PartiallyConstructible {
    /**
      The background color of the introduction screen.
      Default is "?sbColorSurface"
      */
    backgroundColor: string;
    /**
      The divider color of the introduction screen.
      Default is "?sbColorOutline"
      */
    dividerColor: string;
    /**
      The handle color of the introduction screen.
      Default is "?sbColorOutline"
      */
    handlerColor: string;
    /**
      Determines whether the introduction screen should automatically be shown or not when the scanning session starts.
      Default is false
      */
    showAutomatically: boolean;
    /**
      Configuration of the 'done' button, located in the top bar.
      */
    topBarDoneButton: ButtonConfiguration;
    /**
      The title of the introduction screen, located in the top bar.
      */
    title: StyledText;
    /**
      The subtitle of the introduction screen.
      */
    subtitle: StyledText;
    /**
      Configure the scanning steps of the introduction screen.
      */
    items: IntroListEntry[];
    /** @param source {@displayType `DeepPartial<IntroductionScreenConfiguration>`} */
    constructor(source?: DeepPartial<IntroductionScreenConfiguration>);
}
//# sourceMappingURL=IntroductionScreenConfiguration.d.ts.map