import { AcknowledgementBottomBar } from '../document/AcknowledgementScreenConfiguration';
import { AcknowledgementMode } from '../document/AcknowledgementScreenConfiguration';
import { AcknowledgementScreenConfiguration } from '../document/AcknowledgementScreenConfiguration';
import { AspectRatio } from '../common/Common';
import { BackgroundStyle } from '../common/Common';
import { BadgeStyle } from '../common/Common';
import { BarButtonConfiguration } from '../common/Common';
import { ButtonConfiguration } from '../common/Common';
import { CameraModule } from '../common/CameraConfiguration';
import { CameraPermissionScreen } from '../common/CameraPermission';
import { CameraPreviewMode } from '../common/Common';
import { CapturePhotoQualityPrioritization } from '../document/DocumentScannerCameraConfiguration';
import { CheckIntroImage } from '../document/IntroductionScreenConfiguration';
import { CreditCardIntroImage } from '../document/IntroductionScreenConfiguration';
import { CustomImage } from '../document/IntroductionScreenConfiguration';
import { DeepPartial, PartiallyConstructible } from '../../utils';
import { DocumentIntroImage } from '../document/IntroductionScreenConfiguration';
import { DocumentQuality } from '../../document/DocumentQuality';
import { DocumentScannerCameraConfiguration } from '../document/DocumentScannerCameraConfiguration';
import { DocumentScannerUserGuidance } from '../document/DocumentScannerUserGuidance';
import { FinderCorneredStyle } from '../common/ViewFinderConfiguration';
import { FinderStrokedStyle } from '../common/ViewFinderConfiguration';
import { FinderStyle } from '../common/ViewFinderConfiguration';
import { ForegroundStyle } from '../common/Common';
import { IconButton } from '../common/Common';
import { IconStyle } from '../common/Common';
import { IconUserGuidanceConfiguration } from '../common/UserGuidanceConfiguration';
import { IdCardIntroImage } from '../document/IntroductionScreenConfiguration';
import { IntroImage } from '../document/IntroductionScreenConfiguration';
import { IntroListEntry } from '../document/IntroductionScreenConfiguration';
import { IntroductionScreenConfiguration } from '../document/IntroductionScreenConfiguration';
import { MedicalCertificateIntroImage } from '../document/IntroductionScreenConfiguration';
import { NoIntroImage } from '../document/IntroductionScreenConfiguration';
import { PolygonStyle } from '../common/Common';
import { ReceiptsIntroImage } from '../document/IntroductionScreenConfiguration';
import { ScanbotAlertDialog } from '../common/ScanbotAlertDialog';
import { StatusBarMode } from '../common/TopBarConfiguration';
import { StyledText } from '../common/Common';
import { Timeouts } from '../common/Common';
import { UserGuidanceConfiguration } from '../common/UserGuidanceConfiguration';
import { UserGuidanceStates } from '../document/DocumentScannerUserGuidance';
import { UserGuidanceVisibility } from '../document/DocumentScannerGuidanceVisibility';
import { Vibration } from '../common/Common';
import { ViewFinderConfiguration } from '../common/ViewFinderConfiguration';

/**
Configuration of the 'shutter' button.
*/
export class ShutterButton extends PartiallyConstructible {
  /**
    Determines if the 'shutter' button can be tapped to manually snap a document when 'auto snapping mode' is active.
    Default is true
    */
  public enabledInAutoSnappingMode: boolean = true;
  /**
    The text to be read when the 'shutter' button is selected via the accessibility mode.
    Default is "?accessibilityDescriptionCameraShutterButton"
    */
  public accessibilityDescription: string = '?accessibilityDescriptionCameraShutterButton';
  /**
    The outer color of the 'shutter' button.
    Default is "?sbColorOnPrimary"
    */
  public outerColor: string = '?sbColorOnPrimary';
  /**
    The inner color of the 'shutter' button.
    Default is "?sbColorOnPrimary"
    */
  public innerColor: string = '?sbColorOnPrimary';

  /** @param source {@displayType `DeepPartial<ShutterButton>`} */
  public constructor(source: DeepPartial<ShutterButton> = {}) {
    super();
    if (source.enabledInAutoSnappingMode !== undefined) {
      this.enabledInAutoSnappingMode = source.enabledInAutoSnappingMode;
    }
    if (source.accessibilityDescription !== undefined) {
      this.accessibilityDescription = source.accessibilityDescription;
    }
    if (source.outerColor !== undefined) {
      this.outerColor = source.outerColor;
    }
    if (source.innerColor !== undefined) {
      this.innerColor = source.innerColor;
    }
  }
}

export type PreviewButton = PagePreviewMode | TextButtonMode | NoButtonMode;
/** @internal */
export namespace PreviewButton {
  /** @internal */
  export function From(source: { [key: string]: any }): PreviewButton {
    const _type = source._type;
    switch (_type) {
      case 'PagePreviewMode':
        return new PagePreviewMode(source);
      case 'TextButtonMode':
        return new TextButtonMode(source);
      case 'NoButtonMode':
        return new NoButtonMode(source);
      default:
        throw `Unknown child class name: ${_type}`;
    }
  }
}

/**
Configuration of the scan assistance overlay.
*/
export class ScanAssistanceOverlay extends PartiallyConstructible {
  /**
    Determines whether the scan assistance overlay is visible or not. If the viewfinder is enabled, this flag is ignored and the scan assistance overlay is not displayed.
    Default is true
    */
  public visible: boolean = true;
  /**
    The background color of the scan assistance overlay.
    Default is "?sbColorModalOverlay"
    */
  public backgroundColor: string = '?sbColorModalOverlay';
  /**
    The foreground color of the scan assistance overlay image.
    Default is "?sbColorSurface"
    */
  public foregroundColor: string = '?sbColorSurface';

  /** @param source {@displayType `DeepPartial<ScanAssistanceOverlay>`} */
  public constructor(source: DeepPartial<ScanAssistanceOverlay> = {}) {
    super();
    if (source.visible !== undefined) {
      this.visible = source.visible;
    }
    if (source.backgroundColor !== undefined) {
      this.backgroundColor = source.backgroundColor;
    }
    if (source.foregroundColor !== undefined) {
      this.foregroundColor = source.foregroundColor;
    }
  }
}

/**
Configuration of the 'preview' button in 'page preview mode'.
*/
export class PagePreviewMode extends PartiallyConstructible {
  public readonly _type: 'PagePreviewMode' = 'PagePreviewMode';
  /**
    The text to be read when the 'preview' button is selected via the accessibility mode.
    Default is "?accessibilityDescriptionCameraPreviewButton"
    */
  public accessibilityDescription: string = '?accessibilityDescriptionCameraPreviewButton';
  /**
    The color of the image placeholder.
    Default is "?sbColorOnSurfaceVariant"
    */
  public imagePlaceholderColor: string = '?sbColorOnSurfaceVariant';
  /**
    Configuration of the page counter icon.
    */
  public pageCounter: BadgeStyle = new BadgeStyle({
    visible: true,
    background: new BackgroundStyle({
      strokeColor: '?sbColorSurface',
      fillColor: '?sbColorSurface',
    }),
    foregroundColor: '?sbColorPrimary',
  });

  /** @param source {@displayType `DeepPartial<PagePreviewMode>`} */
  public constructor(source: DeepPartial<PagePreviewMode> = {}) {
    super();
    if (source.accessibilityDescription !== undefined) {
      this.accessibilityDescription = source.accessibilityDescription;
    }
    if (source.imagePlaceholderColor !== undefined) {
      this.imagePlaceholderColor = source.imagePlaceholderColor;
    }
    if (source.pageCounter !== undefined) {
      this.pageCounter = new BadgeStyle(source.pageCounter);
    }
  }
}

/**
Configuration of the 'preview' button in 'text button mode'.
*/
export class TextButtonMode extends PartiallyConstructible {
  public readonly _type: 'TextButtonMode' = 'TextButtonMode';
  /**
    The text to be read when the 'preview' button is selected via the accessibility mode.
    Default is "?accessibilityDescriptionCameraPreviewButton"
    */
  public accessibilityDescription: string = '?accessibilityDescriptionCameraPreviewButton';
  /**
    Configuration of the text style for the 'preview' button.
    */
  public style: StyledText = new StyledText({
    text: '?cameraPreviewButtonTitle',
    color: '?sbColorOnPrimary',
  });

  /** @param source {@displayType `DeepPartial<TextButtonMode>`} */
  public constructor(source: DeepPartial<TextButtonMode> = {}) {
    super();
    if (source.accessibilityDescription !== undefined) {
      this.accessibilityDescription = source.accessibilityDescription;
    }
    if (source.style !== undefined) {
      this.style = new StyledText(source.style);
    }
  }
}

/**
Configuration of the 'preview' button in 'no button mode'.
*/
export class NoButtonMode extends PartiallyConstructible {
  public readonly _type: 'NoButtonMode' = 'NoButtonMode';
  /**
    None
    Default is false
    */
  public readonly visible: boolean = false;

  /** @param source {@displayType `DeepPartial<NoButtonMode>`} */
  public constructor(source: DeepPartial<NoButtonMode> = {}) {
    super();
    if (source.visible !== undefined) {
      this.visible = source.visible;
    }
  }
}

/**
Configuration of the bottom bar for the camera screen.
*/
export class CameraBottomBar extends PartiallyConstructible {
  /**
    Configuration of the 'import' button.
    */
  public importButton: BarButtonConfiguration = new BarButtonConfiguration({
    title: new StyledText({
      visible: false,
      text: '?cameraImportButtonTitle',
      color: '?sbColorOnPrimary',
    }),
    accessibilityDescription: '?accessibilityDescriptionCameraImportButton',
    background: new BackgroundStyle({
      strokeColor: '#00000000',
      fillColor: '#00000000',
      strokeWidth: 0.0,
    }),
    icon: new IconStyle({ color: '?sbColorOnPrimary' }),
  });
  /**
    Configuration of the 'auto snapping mode' button.
    */
  public autoSnappingModeButton: BarButtonConfiguration = new BarButtonConfiguration({
    title: new StyledText({
      visible: false,
      text: '?cameraAutoSnapButtonTitle',
      color: '?sbColorOnPrimary',
    }),
    accessibilityDescription: '?accessibilityDescriptionCameraAutoSnapButton',
    background: new BackgroundStyle({
      strokeColor: '#00000000',
      fillColor: '#00000000',
      strokeWidth: 0.0,
    }),
    icon: new IconStyle({ color: '?sbColorOnPrimary' }),
  });
  /**
    Configuration of the 'manual snapping mode' button.
    */
  public manualSnappingModeButton: BarButtonConfiguration = new BarButtonConfiguration({
    title: new StyledText({
      visible: false,
      text: '?cameraManualSnapButtonTitle',
      color: '?sbColorOnPrimary',
    }),
    accessibilityDescription: '?accessibilityDescriptionCameraManualSnapButton',
    background: new BackgroundStyle({
      strokeColor: '#00000000',
      fillColor: '#00000000',
      strokeWidth: 0.0,
    }),
    icon: new IconStyle({ color: '?sbColorOnPrimary' }),
  });
  /**
    Configuration of the 'shutter' button.
    */
  public shutterButton: ShutterButton = new ShutterButton({
    accessibilityDescription: '?accessibilityDescriptionCameraShutterButton',
  });
  /**
    Configuration of the 'flashlight' button when in the 'on' state.
    */
  public torchOnButton: BarButtonConfiguration = new BarButtonConfiguration({
    title: new StyledText({
      visible: false,
      text: '?cameraTorchOnButtonTitle',
      color: '?sbColorOnPrimary',
    }),
    accessibilityDescription: '?accessibilityDescriptionCameraTorchOnButton',
    background: new BackgroundStyle({
      strokeColor: '#00000000',
      fillColor: '#00000000',
      strokeWidth: 0.0,
    }),
    icon: new IconStyle({ color: '?sbColorOnPrimary' }),
  });
  /**
    Configuration of the 'flashlight' button when in the 'off' state.
    */
  public torchOffButton: BarButtonConfiguration = new BarButtonConfiguration({
    title: new StyledText({
      visible: false,
      text: '?cameraTorchOffButtonTitle',
      color: '?sbColorOnPrimary',
    }),
    accessibilityDescription: '?accessibilityDescriptionCameraTorchOffButton',
    background: new BackgroundStyle({
      strokeColor: '#00000000',
      fillColor: '#00000000',
      strokeWidth: 0.0,
    }),
    icon: new IconStyle({ color: '?sbColorOnPrimary' }),
  });
  /**
    Configuration of the 'preview' button.
    */
  public previewButton: PreviewButton = new PagePreviewMode({});

  /** @param source {@displayType `DeepPartial<CameraBottomBar>`} */
  public constructor(source: DeepPartial<CameraBottomBar> = {}) {
    super();
    if (source.importButton !== undefined) {
      this.importButton = new BarButtonConfiguration(source.importButton);
    }
    if (source.autoSnappingModeButton !== undefined) {
      this.autoSnappingModeButton = new BarButtonConfiguration(source.autoSnappingModeButton);
    }
    if (source.manualSnappingModeButton !== undefined) {
      this.manualSnappingModeButton = new BarButtonConfiguration(source.manualSnappingModeButton);
    }
    if (source.shutterButton !== undefined) {
      this.shutterButton = new ShutterButton(source.shutterButton);
    }
    if (source.torchOnButton !== undefined) {
      this.torchOnButton = new BarButtonConfiguration(source.torchOnButton);
    }
    if (source.torchOffButton !== undefined) {
      this.torchOffButton = new BarButtonConfiguration(source.torchOffButton);
    }
    if (source.previewButton !== undefined) {
      this.previewButton = PreviewButton.From(source.previewButton);
    }
  }
}

export type PageSnapFeedbackMode =
  | PageSnapFunnelAnimation
  | PageSnapCheckMarkAnimation
  | PageSnapFeedbackNone;
/** @internal */
export namespace PageSnapFeedbackMode {
  /** @internal */
  export function From(source: { [key: string]: any }): PageSnapFeedbackMode {
    const _type = source._type;
    switch (_type) {
      case 'PageSnapFunnelAnimation':
        return new PageSnapFunnelAnimation(source);
      case 'PageSnapCheckMarkAnimation':
        return new PageSnapCheckMarkAnimation(source);
      case 'PageSnapFeedbackNone':
        return new PageSnapFeedbackNone(source);
      default:
        throw `Unknown child class name: ${_type}`;
    }
  }
}

/**
Configuration of the funnel animation.
*/
export class PageSnapFunnelAnimation extends PartiallyConstructible {
  public readonly _type: 'PageSnapFunnelAnimation' = 'PageSnapFunnelAnimation';
  /**
    The overlay color for the funnel animation.
    Default is "?sbColorModalOverlay"
    */
  public overlayColor: string = '?sbColorModalOverlay';

  /** @param source {@displayType `DeepPartial<PageSnapFunnelAnimation>`} */
  public constructor(source: DeepPartial<PageSnapFunnelAnimation> = {}) {
    super();
    if (source.overlayColor !== undefined) {
      this.overlayColor = source.overlayColor;
    }
  }
}

/**
Configuration of the check mark animation.
*/
export class PageSnapCheckMarkAnimation extends PartiallyConstructible {
  public readonly _type: 'PageSnapCheckMarkAnimation' = 'PageSnapCheckMarkAnimation';
  /**
    The overlay color for the check mark animation.
    Default is "?sbColorModalOverlay"
    */
  public overlayColor: string = '?sbColorModalOverlay';
  /**
    The background color for the check mark animation.
    Default is "?sbColorOutline"
    */
  public checkMarkBackgroundColor: string = '?sbColorOutline';
  /**
    The check mark color for the check mark animation.
    Default is "#00000000"
    */
  public checkMarkColor: string = '#00000000';

  /** @param source {@displayType `DeepPartial<PageSnapCheckMarkAnimation>`} */
  public constructor(source: DeepPartial<PageSnapCheckMarkAnimation> = {}) {
    super();
    if (source.overlayColor !== undefined) {
      this.overlayColor = source.overlayColor;
    }
    if (source.checkMarkBackgroundColor !== undefined) {
      this.checkMarkBackgroundColor = source.checkMarkBackgroundColor;
    }
    if (source.checkMarkColor !== undefined) {
      this.checkMarkColor = source.checkMarkColor;
    }
  }
}

/**
To not use a snap animation.
*/
export class PageSnapFeedbackNone extends PartiallyConstructible {
  public readonly _type: 'PageSnapFeedbackNone' = 'PageSnapFeedbackNone';

  /** @param source {@displayType `DeepPartial<PageSnapFeedbackNone>`} */
  public constructor(source: DeepPartial<PageSnapFeedbackNone> = {}) {
    super();
  }
}

/**
Configuration of the feedback shown after snapping a page.
*/
export class CaptureFeedback extends PartiallyConstructible {
  /**
    Whether the camera preview should blink or not after snapping a page.
    Default is true
    */
  public cameraBlinkEnabled: boolean = true;
  /**
    The type of animation to display after snapping a page.
    */
  public snapFeedbackMode: PageSnapFeedbackMode = new PageSnapFunnelAnimation({});

  /** @param source {@displayType `DeepPartial<CaptureFeedback>`} */
  public constructor(source: DeepPartial<CaptureFeedback> = {}) {
    super();
    if (source.cameraBlinkEnabled !== undefined) {
      this.cameraBlinkEnabled = source.cameraBlinkEnabled;
    }
    if (source.snapFeedbackMode !== undefined) {
      this.snapFeedbackMode = PageSnapFeedbackMode.From(source.snapFeedbackMode);
    }
  }
}

/**
Configuration of the document contour detection polygon.
*/
export class DocumentPolygonConfiguration extends PartiallyConstructible {
  /**
    Determines the visibility mode for the polygon.
    Default is ENABLED
    */
  public visibility: UserGuidanceVisibility = 'ENABLED';
  /**
    Configuration of the polygon when the detected document status is 'OK'.
    */
  public documentOk: PolygonStyle = new PolygonStyle({
    strokeColor: '?sbColorPositive',
    fillColor: '#00000000',
    strokeWidth: 2.0,
  });
  /**
    Configuration of the polygon when the detected document status is 'not OK'.
    */
  public documentNotOk: PolygonStyle = new PolygonStyle({
    strokeColor: '?sbColorNegative',
    fillColor: '#00000000',
    strokeWidth: 2.0,
  });
  /**
    Configuration of the animated polygon when the document is being scanned for capturing in 'auto snapping mode'.
    */
  public autoSnapProgress: PolygonStyle = new PolygonStyle({
    strokeColor: '#40A9FF',
    fillColor: '#00000000',
    strokeWidth: 2.0,
  });

  /** @param source {@displayType `DeepPartial<DocumentPolygonConfiguration>`} */
  public constructor(source: DeepPartial<DocumentPolygonConfiguration> = {}) {
    super();
    if (source.visibility !== undefined) {
      this.visibility = source.visibility;
    }
    if (source.documentOk !== undefined) {
      this.documentOk = new PolygonStyle(source.documentOk);
    }
    if (source.documentNotOk !== undefined) {
      this.documentNotOk = new PolygonStyle(source.documentNotOk);
    }
    if (source.autoSnapProgress !== undefined) {
      this.autoSnapProgress = new PolygonStyle(source.autoSnapProgress);
    }
  }
}

/**
Configuration of the screen for scanning the pages with the camera.
*/
export class CameraScreenConfiguration extends PartiallyConstructible {
  /**
    Configuration of the acknowledgement screen.
    */
  public acknowledgement: AcknowledgementScreenConfiguration =
    new AcknowledgementScreenConfiguration({});
  /**
    Configuration of the introduction screen.
    */
  public introduction: IntroductionScreenConfiguration = new IntroductionScreenConfiguration({});
  /**
    Configuration of the scan assistance overlay.
    */
  public scanAssistanceOverlay: ScanAssistanceOverlay = new ScanAssistanceOverlay({});
  /**
    Configuration of the camera permission screen.
    */
  public cameraPermission: CameraPermissionScreen = new CameraPermissionScreen({
    statusBarMode: 'DARK',
    background: '?sbColorSurface',
    iconBackground: '?sbColorOutline',
    icon: new IconStyle({ visible: true, color: '?sbColorOnSurface' }),
    enableCameraButton: new ButtonConfiguration({
      visible: true,
      text: '?cameraPermissionEnableCameraButton',
      accessibilityDescription: '?accessibilityDescriptionCameraPermissionEnableCameraButton',
      background: new BackgroundStyle({
        strokeColor: '?sbColorPrimary',
        fillColor: '?sbColorPrimary',
        strokeWidth: 0.0,
      }),
      foreground: new ForegroundStyle({
        iconVisible: false,
        color: '?sbColorOnPrimary',
        useShadow: false,
      }),
    }),
    closeButton: new ButtonConfiguration({
      visible: true,
      text: '?cameraPermissionCloseButton',
      accessibilityDescription: '?accessibilityDescriptionCameraPermissionCloseButton',
      background: new BackgroundStyle({
        strokeColor: '#00000000',
        fillColor: '#00000000',
        strokeWidth: 0.0,
      }),
      foreground: new ForegroundStyle({
        iconVisible: false,
        color: '?sbColorPrimary',
        useShadow: false,
      }),
    }),
    enableCameraTitle: new StyledText({
      text: '?cameraPermissionEnableCameraTitle',
      color: '?sbColorOnSurface',
    }),
    enableCameraExplanation: new StyledText({
      text: '?cameraPermissionEnableCameraExplanation',
      color: '?sbColorOnSurfaceVariant',
    }),
  });
  /**
    Configuration of the title, located in the top bar.
    */
  public topBarTitle: StyledText = new StyledText({
    text: '?cameraTopBarTitle',
    color: '?sbColorOnPrimary',
  });
  /**
    Configuration of the 'introduction' button, located in the top bar.
    */
  public topBarIntroButton: IconButton = new IconButton({
    color: '?sbColorOnPrimary',
    accessibilityDescription: '?accessibilityDescriptionCameraTopBarIntroButton',
  });
  /**
    Configuration of the 'cancel' button, located in the top bar.
    */
  public topBarBackButton: ButtonConfiguration = new ButtonConfiguration({
    visible: true,
    text: '?cameraTopBarCancelButtonTitle',
    accessibilityDescription: '?accessibilityDescriptionCameraTopBarCancelButton',
    background: new BackgroundStyle({
      strokeColor: '#00000000',
      fillColor: '#00000000',
      strokeWidth: 0.0,
    }),
    foreground: new ForegroundStyle({
      iconVisible: true,
      color: '?sbColorOnPrimary',
      useShadow: false,
    }),
  });
  /**
    Configuration of the static user guidance, located just below the top bar.
    */
  public topUserGuidance: UserGuidanceConfiguration = new UserGuidanceConfiguration({
    title: new StyledText({ text: '?cameraTopGuidance', color: '?sbColorOnPrimary' }),
  });
  /**
    Configuration of the hints guiding users through the scanning process.
    */
  public userGuidance: DocumentScannerUserGuidance = new DocumentScannerUserGuidance({});
  /**
    The background color of the camera screen.
    Default is "#000000FF"
    */
  public backgroundColor: string = '#000000FF';
  /**
    Configuration of the camera behavior.
    */
  public cameraConfiguration: DocumentScannerCameraConfiguration =
    new DocumentScannerCameraConfiguration({});
  /**
    Configuration of the document contour detection polygon.
    */
  public polygon: DocumentPolygonConfiguration = new DocumentPolygonConfiguration({});
  /**
    Configuration of the bottom bar for the camera screen.
    */
  public bottomBar: CameraBottomBar = new CameraBottomBar({});
  /**
    Configuration of the viewfinder.
    */
  public viewFinder: ViewFinderConfiguration = new ViewFinderConfiguration({
    visible: false,
    aspectRatio: new AspectRatio({ width: 21.0, height: 29.0 }),
  });
  /**
    Configuration of the feedback shown after snapping a page.
    */
  public captureFeedback: CaptureFeedback = new CaptureFeedback({});
  /**
    Configuration of the scan confirmation vibration.
    */
  public vibration: Vibration = new Vibration({ enabled: true });
  /**
    Configuration of timeouts.
    */
  public timeouts: Timeouts = new Timeouts({ autoCancelTimeout: 0, initialScanDelay: 0 });
  /**
    Configuration of the alert dialog displayed when the scan limit is reached.
    */
  public limitReachedAlertDialog: ScanbotAlertDialog = new ScanbotAlertDialog({
    title: new StyledText({ text: '?cameraLimitReachedAlertTitle', color: '?sbColorOnSurface' }),
    subtitle: new StyledText({
      text: '?cameraLimitReachedAlertSubtitle',
      color: '?sbColorOnSurfaceVariant',
    }),
    okButton: new ButtonConfiguration({
      text: '?cameraLimitReachedOkButtonTitle',
      accessibilityDescription: '?accessibilityDescriptionCameraLimitReachedOkButton',
      background: new BackgroundStyle({ fillColor: '?sbColorPrimary', strokeWidth: 0.0 }),
      foreground: new ForegroundStyle({ color: '?sbColorOnPrimary' }),
    }),
    cancelButton: new ButtonConfiguration({ visible: false }),
  });
  /**
    Configuration of the alert dialog displayed when the 'cancel' button is pressed.
    */
  public cancelAlertDialog: ScanbotAlertDialog = new ScanbotAlertDialog({
    title: new StyledText({ text: '?cameraCancelAlertTitle', color: '?sbColorOnSurface' }),
    subtitle: new StyledText({
      text: '?cameraCancelAlertSubtitle',
      color: '?sbColorOnSurfaceVariant',
    }),
    okButton: new ButtonConfiguration({
      text: '?cameraCancelYesButtonTitle',
      accessibilityDescription: '?accessibilityDescriptionCameraCancelYesButton',
      background: new BackgroundStyle({ fillColor: '?sbColorPrimary', strokeWidth: 0.0 }),
      foreground: new ForegroundStyle({ color: '?sbColorOnPrimary' }),
    }),
    cancelButton: new ButtonConfiguration({
      text: '?cameraCancelNoButtonTitle',
      accessibilityDescription: '?accessibilityDescriptionCameraCancelNoButton',
      background: new BackgroundStyle({ fillColor: '#00000000', strokeWidth: 0.0 }),
      foreground: new ForegroundStyle({ color: '?sbColorPrimary' }),
    }),
  });

  /** @param source {@displayType `DeepPartial<CameraScreenConfiguration>`} */
  public constructor(source: DeepPartial<CameraScreenConfiguration> = {}) {
    super();
    if (source.acknowledgement !== undefined) {
      this.acknowledgement = new AcknowledgementScreenConfiguration(source.acknowledgement);
    }
    if (source.introduction !== undefined) {
      this.introduction = new IntroductionScreenConfiguration(source.introduction);
    }
    if (source.scanAssistanceOverlay !== undefined) {
      this.scanAssistanceOverlay = new ScanAssistanceOverlay(source.scanAssistanceOverlay);
    }
    if (source.cameraPermission !== undefined) {
      this.cameraPermission = new CameraPermissionScreen(source.cameraPermission);
    }
    if (source.topBarTitle !== undefined) {
      this.topBarTitle = new StyledText(source.topBarTitle);
    }
    if (source.topBarIntroButton !== undefined) {
      this.topBarIntroButton = new IconButton(source.topBarIntroButton);
    }
    if (source.topBarBackButton !== undefined) {
      this.topBarBackButton = new ButtonConfiguration(source.topBarBackButton);
    }
    if (source.topUserGuidance !== undefined) {
      this.topUserGuidance = new UserGuidanceConfiguration(source.topUserGuidance);
    }
    if (source.userGuidance !== undefined) {
      this.userGuidance = new DocumentScannerUserGuidance(source.userGuidance);
    }
    if (source.backgroundColor !== undefined) {
      this.backgroundColor = source.backgroundColor;
    }
    if (source.cameraConfiguration !== undefined) {
      this.cameraConfiguration = new DocumentScannerCameraConfiguration(source.cameraConfiguration);
    }
    if (source.polygon !== undefined) {
      this.polygon = new DocumentPolygonConfiguration(source.polygon);
    }
    if (source.bottomBar !== undefined) {
      this.bottomBar = new CameraBottomBar(source.bottomBar);
    }
    if (source.viewFinder !== undefined) {
      this.viewFinder = new ViewFinderConfiguration(source.viewFinder);
    }
    if (source.captureFeedback !== undefined) {
      this.captureFeedback = new CaptureFeedback(source.captureFeedback);
    }
    if (source.vibration !== undefined) {
      this.vibration = new Vibration(source.vibration);
    }
    if (source.timeouts !== undefined) {
      this.timeouts = new Timeouts(source.timeouts);
    }
    if (source.limitReachedAlertDialog !== undefined) {
      this.limitReachedAlertDialog = new ScanbotAlertDialog(source.limitReachedAlertDialog);
    }
    if (source.cancelAlertDialog !== undefined) {
      this.cancelAlertDialog = new ScanbotAlertDialog(source.cancelAlertDialog);
    }
  }
}
